# Copyright (C) 2010  W. Trevor King <wking@drexel.edu>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# The author may be contacted at <wking@drexel.edu> on the Internet, or
# write to Trevor King, Drexel University, Physics Dept., 3141 Chestnut St.,
# Philadelphia PA 19104, USA.

"""Wrap `sawsim` to facilitate more complicated analysis.

Testing pysawsim
================

pysawsim's test framework is build using doctest_, unittest_, and nose_.
`nosetests` (from the nose_ package) scans through the source tree,
searching out the various tests and running them.  If you aren't
familiar with nose_, there is excellent documentation on its home
page.  We use nose_ because its auto-discovery allows us to avoid
collecting all of our assorted tests into
:class:`unittest.TestSuite`\s and running them by hand.

To run the test suite from the sawsim installation directory, just use::

    nosetests --with-doctest --doctest-tests pysawsim/

.. _doctest: http://docs.python.org/library/doctest.html
.. _unittest: http://docs.python.org/library/unittest.html
.. _nose: http://somethingaboutorange.com/mrl/projects/nose/0.11.3/


Adding tests to modules
-----------------------

Just go crazy with doctests and unittests; nose_ will find them.
"""

import logging
import logging.handlers
import sys


__version__ = '0.10'  # match sawsim version

def log():
    return logging.getLogger('pysawsim')

_log = log()
_log.setLevel(logging.DEBUG)
_console = logging.StreamHandler()
_formatter = logging.Formatter('%(name)-8s: %(levelname)-6s %(message)s')
_console.setFormatter(_formatter)
_log.addHandler(_console)
del(_log)
del(_console)
del(_formatter)
